@@ -11,18 +11,20 @@ def identifier_conversion(input_type, compound_list):
     Returns:
         (pd.DataFrame) Dataframe containing identifier matches 
     """
-    url = "http://api.xialab.ca/mapcompounds"
+    url = "https://www.xialab.ca/api/mapcompounds"
+    print('Commencing ID conversion using Metaboanalyst API...')
 
     resps = []
     for i in range(0, len(compound_list), 100):
         cpds = compound_list[i:i+100]
-        input_cpds = {"queryList": cpds, "inputType": input_type}
+        input_cpds = {"queryList": ';'.join(cpds), "inputType": input_type}
         headers = {
-            # 'Content-Type': "application/json",
+            'Content-Type': "application/json",
             'cache-control': "no-cache",
             }
 
         response = requests.request("POST", url, json=input_cpds, headers=headers)
+        
         resp_dict = response.json()
         resps.append(resp_dict)
 
@@ -49,4 +51,4 @@ def map_identifiers(query_df, output_id_type, matrix):
     cpd_mapping_dict = {k: v for k, v in cpd_mapping_dict.items() if v not in ["NA", np.nan, None, "None"]}
     renamed_mat = matrix.drop([i for i in matrix.columns if i not in cpd_mapping_dict.keys()], axis=1)
     renamed_mat = renamed_mat.rename(cpd_mapping_dict, axis=1)
-    return renamed_mat
\ No newline at end of file
+    return renamed_mat
